@@ -91,7 +91,7 @@
 				 */
 				$page = array(
 					"url"      => "/",
-					"language" => DEFAULT_LANGUAGE,
+					"language" => $this->settings->default_language,
 					"visible"  => 1,
 					"roles"    => array());
 				$this->show_page_form($page);
