@@ -4,7 +4,7 @@
 			if (isset($_SESSION["user_switch"])) {
 				/* User switch already active
 				 */
-				$this->output->add_tag("result", "User switch already active.", array("url" => START_PAGE));
+				$this->output->add_tag("result", "User switch already active.", array("url" => $this->settings->start_page));
 			} else if ($_SERVER["REQUEST_METHOD"] == "POST") {
 				/* Switch user
 				 */
@@ -16,7 +16,7 @@
 					$this->user->log_action("switched to user_id ".$_POST["user_id"]);
 					$_SESSION["user_switch"] = $_SESSION["user_id"];
 					$_SESSION["user_id"] = (int)$_POST["user_id"];
-					$this->output->add_tag("result", "User switch successfull.", array("url" => START_PAGE));
+					$this->output->add_tag("result", "User switch successfull.", array("url" => $this->settings->start_page));
 				}
 			} else {
 				/* Show user list
