@@ -7,9 +7,9 @@
 			$this->output->open_tag("edit");
 			$this->output->add_tag("email", $profile["email"]);
 			if ($this->user->status == USER_STATUS_CHANGEPWD) {
-				$this->output->add_tag("cancel", "Logout", array("page" => "logout"));
+				$this->output->add_tag("cancel", "Logout", array("page" => LOGOUT_MODULE));
 			} else {
-				$this->output->add_tag("cancel", "Back", array("page" => START_PAGE));
+				$this->output->add_tag("cancel", "Back", array("page" => $this->settings->start_page));
 			}
 			$this->output->close_tag();
 		}
@@ -27,7 +27,7 @@
 				} else if ($this->model->update_profile($_POST) === false) {
 					$this->output->add_tag("result", "Error while updating profile.", array("url" => "profile"));
 				} else {
-					$this->output->add_tag("result", "Profile has been updated.", array("url" => START_PAGE));
+					$this->output->add_tag("result", "Profile has been updated.", array("url" => $this->settings->start_page));
 					$this->user->log_action("profile updated");
 				}
 			} else {
