@@ -221,7 +221,7 @@
 					$content = wordwrap($content, 75, "\n", true);
 					$message .=
 						"--".$this->boundary."\n".
-						"Content-Disposition: inline\n".
+						"Content-Disposition: attachment;\n".
 						"\tfilename=".$attachment["filename"]."\n".
 						"Content-Type: ".$attachment["content_type"]."\n".
 						"Content-Transfer-Encoding: base64\n\n".
