@@ -3,9 +3,39 @@
 	 *
 	 * Copyright (C) by Hugo Leisink <hugo@leisink.net>
 	 * This file is part of the Banshee PHP framework
-	 * http://www.hiawatha-webserver.org/banshee
+	 * http://www.banshee-php.org/
 	 */
 
+	/* Convert mixed to boolean
+	 *
+	 * INPUT:  mixed
+	 * OUTPUT: boolean
+	 * ERROR:  -
+	 */
+	function is_true($bool) {
+		return in_array($bool, array(true, YES, "1", "yes", "true", "on"), true);
+	}
+
+	/* Convert mixed to boolean
+	 *
+	 * INPUT:  mixed
+	 * OUTPUT: boolean
+	 * ERROR:  -
+	 */
+	function is_false($bool) {
+		return (is_true($bool) === false);
+	}
+
+	/* Convert boolean to string
+	 *
+	 * INPUT:  boolean
+	 * OUTPUT: string "yes"|"no"
+	 * ERROR:  -
+	 */
+	function show_boolean($bool) {
+		return (is_true($bool) ? "yes" : "no");
+	}
+
 	/* Convert a page path to a module path
 	 *
 	 * INPUT:  array / string page path
@@ -14,7 +44,11 @@
 	 */
 	function page_to_module($page) {
 		if (is_array($page) == false) {
-			return str_replace("*/", "", $page);
+			$page = str_replace("*/", "", $page);
+
+			if (($pos = strrpos($page, ".")) !== false) {
+				$page = substr($page, 0, $pos);
+			}
 		} else foreach ($page as &$item) {
 			$item = page_to_module($item);
 		}
@@ -22,6 +56,39 @@
 		return $page;
 	}
 
+	/* Convert a page path to a module path
+	 *
+	 * INPUT:  array / string page path
+	 * OUTPUT: array / string page type
+	 * ERROR:  -
+	 */
+	function page_to_type($page) {
+		if (is_array($page) == false) {
+			if (($pos = strrpos($page, ".")) !== false) {
+				$page = substr($page, $pos);
+			} else {
+				$page = "";
+			}
+		} else foreach ($page as &$item) {
+			$item = page_to_type($item);
+		}
+
+		return $page;
+	}
+
+	/* Get users in group
+	 *
+	 * INPUT:  string group name
+	 * OUTPUT: array user
+	 * ERROR:  false
+	 */
+	function users_in_group($db, $group) {
+		$query = "select distinct u.* from users u, user_role m, roles r ".
+		         "where r.name=%s and r.id=m.role_id and m.user_id=u.id";
+
+		return $db->execute($query, $group);
+	}
+
 	/* Flatten array to new array with depth 1
 	 *
 	 * INPUT:  array
@@ -80,6 +147,26 @@
 		return $str;
 	}
 
+	/* Prepare data for CSV output
+	 *
+	 * INPUT:  string/array data
+	 * OUTPUT: string data
+	 * ERROR:  -
+	 */
+	function csv_output($data) {
+		if (is_array($data) == false) {
+			$data = str_replace('"', '""', $data);
+			$data = '"'.$data.'"';
+		} else {
+			foreach ($data as &$item) {
+				$item = csv_output($item);
+			}
+			$data = implode(",", $data);
+		}
+
+		return $data;
+	}
+
 	/* Prepare string for iCalendar output
 	 *
 	 * INPUT:  string data
@@ -193,23 +280,60 @@
 		return $html;
 	}
 
+	/* Perform HTTP GET request and follow redirects
+	 *
+	 * INPUT:  string URL[, int redirect limit]
+	 * OUTPUT: array HTTP result
+	 * ERROR:  false
+	 */
+	function follow_http_redirects($url, $redirects = 5) {
+		$result = false;
+
+		while ($redirects-- >= 0) {
+			list($protocol,, $hostname, $path) = explode("/", $url, 4);
+
+			if ($protocol == "http:") {
+				$http = new http($hostname);
+			} else if ($protocol == "https:") {
+				$http = new https($hostname);
+			} else {
+				break;
+			}
+
+			$result = $http->GET("/".$path);
+			unset($http);
+
+			if ($result === false) {
+				break;
+			} else if (($result["status"] != 301) && ($result["status"] != 302)) {
+				break;
+			} else if (($url = $result["headers"]["Location"]) == "") {
+				break;
+			}
+		}
+
+		return $result;
+	}
+
 	/* Decode a GZip encoded string
 	 *
-	 * INPUT:  string
-	 * OUTPUT: string
+	 * INPUT:  string GZip data
+	 * OUTPUT: string data
 	 * ERROR:  -
 	 */
-	if (version_compare(PHP_VERSION, "6.0.0", "<")) {
-		function gzdecode($data) {
-			$file = tempnam("/tmp", "gzip");
+	if (function_exists("gzdecode") == false) {
 
-			@file_put_contents($file, $data);
-			ob_start();
-			readgzfile($file);
-			$data = ob_get_clean();
-			unlink($file);
+	function gzdecode($data) {
+		$file = tempnam("/tmp", "gzip");
+
+		@file_put_contents($file, $data);
+		ob_start();
+		readgzfile($file);
+		$data = ob_get_clean();
+		unlink($file);
+
+		return $data;
+	}
 
-			return $data;
-		}
 	}
 ?>
