@@ -4,42 +4,49 @@
 	 * Copyright (C) by Hugo Leisink <hugo@leisink.net>
 	 * This file is part of the Banshee PHP framework
 	 * http://www.banshee-php.org/
+	 *
+	 * Don't change this file, unless you know what you are doing.
 	 */
 
-	class output extends XML {
+	final class output extends XML {
+		private $settings = null;
 		private $page = null;
-		private $language = DEFAULT_LANGUAGE;
-		private $description = HEAD_DESCRIPTION;
-		private $keywords = HEAD_KEYWORDS;
+		private $language = null;
+		private $description = null;
+		private $keywords = null;
+		private $system_messages = arraY();
 		private $messages = array();
 		private $javascripts = array();
-		private $onload_javascript = null;
+		private $onload_javascript = array();
 		private $alternates = array();
 		private $title = null;
 		private $css_links = array();
 		private $inline_css = null;
 		private $content_type = "text/html; charset=utf-8";
 		private $layout = "layout_site";
+		private $disabled = false;
 
 		/* Constructor
 		 *
-		 * INPUT:  object database, boolean AJAX request
+		 * INPUT:  object database, object settings, object page
 		 * OUTPUT: -
 		 * ERROR:  -
 		 */
-		public function __construct($db, $page) {
-			ob_start();
-			set_exception_handler(array($this, "exception_handler"));
-			set_error_handler(array($this, "error_handler"), E_ALL & ~E_NOTICE);
+		public function __construct($db, $settings, $page) {
+			$this->language = $settings->default_language;
+			$this->description = $settings->head_description;
+			$this->keywords = $settings->head_keywords;
 
+			$this->settings = $settings;
 			$this->page = $page;
 			parent::__construct($db);
 
 			/* Page layout
 			 */
+			$inherit_layout = array(LOGOUT_MODULE, "password");
 			if (substr($this->page->url, 0, 6) == "/admin") {
 				$this->layout = "layout_cms";
-			} else if (in_array($this->page->module, array(LOGIN_PAGE, LOGOUT_PAGE, "password"))) {
+			} else if (in_array($this->page->module, $inherit_layout)) {
 				if ($_SESSION["previous_layout"] == "layout_cms") {
 					$this->layout = "layout_cms";
 				}
@@ -71,6 +78,7 @@
 				case "inline_css": return $this->inline_css;
 				case "content_type": return $this->content_type;
 				case "layout": return $this->layout;
+				case "disabled": return $this->disabled;
 			}
 
 			return parent::__get($key);
@@ -90,30 +98,11 @@
 				case "title": $this->title = $value; break;
 				case "inline_css": $this->inline_css = $value; break;
 				case "content_type": $this->content_type = $value; break;
+				case "disabled": $this->disabled = $value; break;
 				default: trigger_error("Unknown output variable: ".$key);
 			}
 		}
 
-		/* Exception handler
-		 *
-		 * INPUT:  error object
-		 * OUTPUT: -
-		 * ERROR:  -
-		 */
-		public function exception_handler($error) {
-			print "Caught exception '".$error->getmessage()."'<br />\n";
-		}
-
-		/* Error handler
-		 *
-		 * INPUT:  int error number, string error string, string filename, int line number
-		 * OUTPUT: -
-		 * ERROR:  -
-		 */
-		public function error_handler($errno, $errstr, $errfile, $errline) {
-			print $errstr." in ".$errfile." on line ".$errline.".<br />\n";
-		}
-
 		/* Add CSS link to output
 		 *
 		 * INPUT:  string CSS filename
@@ -162,7 +151,7 @@
 		 * ERROR:  -
 		 */
 		public function onload_javascript($function) {
-			$this->onload_javascript = $function;
+			array_push($this->onload_javascript, rtrim($function, ";").";");
 		}
 
 		/* Add alternate link
@@ -194,16 +183,24 @@
 			return true;
 		}
 
+		/* Add system message to message buffer
+		 *
+		 * input:  string message
+		 * output: -
+		 * error:  -
+		 */
+		public function add_system_message($message) {
+			array_push($this->system_messages, $message);
+		}
+
 		/* Add message to message buffer
 		 *
-		 * INPUT:  string message, int message type
-		 * OUTPUT: -
-		 * ERROR:  -
+		 * input:  string message
+		 * output: -
+		 * error:  -
 		 */
-		public function add_message($message, $type = 0) {
-			array_push($this->messages, array(
-				"content" => $message,
-				"type"    => $type));
+		public function add_message($message) {
+			array_push($this->messages, $message);
 		}
 
 		/* Close XML tag
@@ -216,11 +213,21 @@
 			if (($this->page->ajax_request == false) && ($this->depth == 1)) {
 				/* Messages
 				 */
-				$this->open_tag("messages");
-				foreach ($this->messages as $message) {
-					$this->add_tag("message", $message["content"], array("type" => $message["type"]));
+				if (count($this->system_messages) > 0) {
+					$this->open_tag("system_messages");
+					foreach ($this->system_messages as $message) {
+						$this->add_tag("message", $message);
+					}
+					$this->close_tag();
+				}
+
+				if (count($this->messages) > 0) {
+					$this->open_tag("messages");
+					foreach ($this->messages as $message) {
+						$this->add_tag("message", $message);
+					}
+					$this->close_tag();
 				}
-				$this->close_tag();
 
 				$this->open_tag($this->layout);
 
@@ -228,7 +235,7 @@
 				 */
 				$this->add_tag("description", $this->description);
 				$this->add_tag("keywords", $this->keywords);
-				$this->add_tag("title", ($this->title != null ? $this->title." - " : "").HEAD_TITLE);
+				$this->add_tag("title", $this->settings->head_title, array("page" => $this->title));
 				$this->add_tag("language", $this->language);
 
 				/* Cascading Style Sheets
@@ -243,8 +250,8 @@
 				/* Javascripts
 				 */
 				$params = array();
-				if ($this->onload_javascript !== null) {
-					$params["onload"] = $this->onload_javascript;
+				if (count($this->onload_javascript) > 0) {
+					$params["onload"] = implode(" ", $this->onload_javascript);
 				}
 				$this->open_tag("javascripts", $params);
 				foreach ($this->javascripts as $javascript) {
@@ -262,12 +269,6 @@
 				}
 				$this->close_tag();
 
-				/* Google Analytics
-				 */
-				if (GOOGLE_ANALYTICS != "") {
-					$this->add_tag("google_analytics", GOOGLE_ANALYTICS);
-				}
-
 				$this->close_tag();
 			}
 
@@ -277,8 +278,8 @@
 		/* Mask transform function
 		 *
 		 * INPUT:  -
-		 * OUTPUT: -
-		 * ERROR:  false
+		 * OUTPUT: false
+		 * ERROR:  -
 		 */
 		public function transform() {
 			return false;
@@ -291,8 +292,9 @@
 		 * ERROR:  -
 		 */
 		public function generate($output, $view = null) {
-			$errors = trim(ob_get_contents());
-			ob_end_clean();
+			if ($this->disabled) {
+				return;
+			}
 
 			if (($output == null) && $this->page->ajax_request) {
 				$output = "xml";
@@ -305,52 +307,14 @@
 					break;
 				case "data":
 					header("Content-Type: text/plain");
-					if (is_true(DEBUG) && (strlen($errors) > 0)) {
-						print $errors."\n".str_repeat("-", 80)."\n";
-					}
 					print $this->document;
 					break;
 				case null:
-					$this->set_xslt_parameter("layout", "site");
-
 					if (($html = parent::transform($view)) === false) {
 						print "XSL Transformation error";
 						return;
 					}
 
-					if (strlen($errors) > 0) {
-						$errors = str_replace("<br />", "", $errors);
-						if (is_true(DEBUG)) { 
-							$html .= "<fieldset id=\"internal_errors\" class=\"internal_errors\">";
-							$html .= "<legend>Internal errors <img src=\"/images/cross.gif\" title=\"Close message box\" alt=\"Close\" class=\"close\" onClick=\"javascript:document.getElementById('internal_errors').style.display = 'none'\"></legend>\n";
-
-							$errors = htmlentities($errors);
-							$errors = str_replace("\t", "    ", $errors);
-							$errors = explode("\n", $errors);
-							foreach ($errors as $error) {
-								$len = strlen($error);
-								$error = ltrim($error);
-								if (($len = $len - strlen($error)) > 0) {
-									$html .= str_repeat("&nbsp;", $len);
-								}
-								$html .= $error."<br />\n";
-							}
-
-							$html .= "</fieldset>\n";
-						} else {
-							$message =
-								"Date, time: ".date("j F Y, H:i:s")."\n".
-								"Used URL  : ".$_SERVER["REQUEST_URI"]."\n".
-								"IP address: ".$_SERVER["REMOTE_ADDR"]."\n".
-								"User-Agent: ".$_SERVER["HTTP_USER_AGENT"]."\n".
-								"\n".$errors;
-
-							$email = new email("Internal error at ".$_SERVER["SERVER_NAME"], "no-reply@".$_SERVER["SERVER_NAME"]);
-							$email->message($message);
-							$email->send(WEBMASTER_EMAIL);
-						}
-					}
-
 					/* GZip content encoding
 					 */
 					$encodings = $_SERVER["HTTP_ACCEPT_ENCODING"];
