@@ -8,8 +8,9 @@
 	 * Don't change this file, unless you know what you are doing.
 	 */
 
-	class page {
+	final class page {
 		private $db = null;
+		private $settings = null;
 		private $user = null;
 		private $module = null;
 		private $url = null;
@@ -18,20 +19,27 @@
 		private $http_code = 200;
 		private $is_public = true;
 		private $pathinfo = array();
+		private $parameters = array();
 		private $ajax_request = null;
 
 		/* Constructor
 		 *
-		 * INPUT:  object database, object user, boolean AJAX request
+		 * INPUT:  object database, object settings, object user
 		 * OUTPUT: -
 		 * ERROR:  -
 		 */
-		public function __construct($db, $user) {
+		public function __construct($db, $settings, $user) {
 			$this->db = $db;
+			$this->settings = $settings;
 			$this->user = $user;
-			$this->ajax_request = $_ENV["HTTP_X_REQUEST_TYPE"] == "AJAX";
-			if (is_true(DEBUG) && ($this->ajax_request == false)) {
-				$this->ajax_request = $_GET["banshee_ajax"] !== null;
+			$this->ajax_request = $_ENV["HTTP_X_REQUESTED_WITH"] == "XMLHttpRequest";
+			if ($_GET["output"] == "ajax") {
+				if (is_true(DEBUG_MODE)) {
+					$this->ajax_request = true;
+					$_GET["output"] = "xml";
+				} else {	
+					unset($_GET["output"]);
+				}
 			}
 
 			/* Prevent Cross-Site Request Forgery
@@ -49,13 +57,13 @@
 			if (is_false(WEBSITE_ONLINE) && ($_SERVER["REMOTE_ADDR"] != WEBSITE_ONLINE)) {
 				$page = "offline";
 			} else if ($db->connected == false) {
-				$page = "error";
+				$page = ERROR_MODULE;
 				$this->http_code = 500;
 			} else {
 				list($this->url) = explode("?", $_SERVER["REQUEST_URI"], 2);
 				$path = trim($this->url, "/");
 
-				$page = valid_input($path, VALIDATE_URL, VALIDATE_NONEMPTY) ? $path : START_PAGE;
+				$page = valid_input($path, VALIDATE_URL, VALIDATE_NONEMPTY) ? $path : $this->settings->start_page;
 				$this->pathinfo = secure_input(explode("/", $page));
 			}
 
@@ -87,6 +95,7 @@
 				case "type": return ltrim($this->type, ".");
 				case "view": return $this->module.$this->type;
 				case "pathinfo": return $this->pathinfo;
+				case "parameters": return $this->parameters;
 				case "http_code": return $this->http_code;
 				case "ajax_request": return $this->ajax_request;
 				case "is_public": return $this->is_public;
@@ -123,15 +132,7 @@
 
 				if ($match && (strlen($line) >= strlen($module))) {
 					$module = page_to_module($line);
-				}
-			}
-
-			/* Determine page type
-			 */
-			if ($module !== null) {
-				if (($pos = strrpos($module, ".")) !== false) {
-					$this->type = substr($module, $pos);
-					$module = substr($module, 0, $pos);
+					$this->type = page_to_type($line);
 				}
 			}
 
@@ -168,7 +169,7 @@
 		 * ERROR:  -
 		 */
 		public function select_module($page) {
-			if (($this->module !== null) && ($this->module !== LOGIN_PAGE)) {
+			if (($this->module !== null) && ($this->module !== LOGIN_MODULE)) {
 				return;
 			}
 
@@ -191,6 +192,8 @@
 			/* Public page
 			 */
 			if (($this->module = $this->page_on_disk($page, "public_pages")) !== null) {
+				$module_count = substr_count($this->module, "/") + 1;
+				$this->parameters = array_slice($this->pathinfo, $module_count);
 				return;
 			} else if (($this->module = $this->page_in_database($page, NO)) !== null) {
 				return;
@@ -198,7 +201,7 @@
 
 			/* Change profile before access to private pages
 			 */
-			if ($this->user->logged_in && ($page != LOGOUT_PAGE)) {
+			if ($this->user->logged_in && ($page != LOGOUT_MODULE)) {
 				if ($this->user->status == USER_STATUS_CHANGEPWD) {
 					$page = "profile";
 					$this->type = "";
@@ -214,25 +217,29 @@
 			if ($this->module == null) {
 				/* Page does not exist.
 				 */
-				$this->module = "error";
+				$this->module = ERROR_MODULE;
 				$this->http_code = 404;
 				$this->type = "";
 			} else if ($this->user->logged_in == false) {
 				/* User not logged in.
 				 */
-				$this->module = LOGIN_PAGE;
+				$this->module = LOGIN_MODULE;
 				$this->type = "";
 			} else if ($this->user->access_allowed($this->__get("page").$this->type) == false) {
 				/* Access denied because not with right role.
 				 */
-				$this->module = "error";
+				$this->module = ERROR_MODULE;
 				$this->http_code = 401;
 				$this->type = "";
+				$this->user->log_action("unauthorized request for page %s", $page);
 			} else {
 				/* Access allowed.
 				 */
 				$this->is_public = false;
 				$_SESSION["last_private_visit"] = time();
+
+				$module_count = substr_count($this->module, "/") + 1;
+				$this->parameters = array_slice($this->pathinfo, $module_count);
 			}
 		}
 	}
