@@ -3,51 +3,55 @@
 	 *
 	 * Copyright (C) by Hugo Leisink <hugo@leisink.net>
 	 * This file is part of the Banshee PHP framework
-	 * http://www.hiawatha-webserver.org/banshee
+	 * http://www.banshee-php.org/
 	 */
 
-	/* Remove dangerous characters from string
+	/* Abort execution upon dangerous PHP setting
 	 *
-	 * INPUT:  string text
-	 * OUTPUT: string text
+	 * INPUT:  string key, mixed value
+	 * OUTPUT: -
 	 * ERROR:  -
 	 */
-	function secure_input($data) {
+	function check_PHP_setting($key, $value) {
+		if (ini_get($key) != $value) {
+			exit("Please, set the PHP flag '".$key."' to '".$value."'!\n");
+		}
+	}
+
+	/* Remove magic quotes from string
+	 *
+	 * INPUT:  array/string data
+	 * OUTPUT: array/string data
+	 * ERROR:  -
+	 */
+	function remove_magic_quotes($data) {
 		if (is_array($data) == false) {
-			$data = utf8_decode($data);
-			if (get_magic_quotes_gpc() == 1) {
-				$data = stripslashes($data);
-			}
-			$data = str_replace(chr(0), "", $data);
-			$special_chars = "/[".chr(1)."-".chr(8)."]|".
-			                  "[".chr(11).chr(12)."]|".
-			                  "[".chr(14)."-".chr(31)."]/";
-			$data = preg_replace($special_chars, "", $data);
-		} else foreach ($data as $key => $value) {
-			$data[$key] = secure_input($value);
+			$data = stripslashes($data);
+		} else foreach ($data as &$value) {
+			$value = remove_magic_quotes($value);
 		}
 
 		return $data;
 	}
 
-	/* Exit if client's IP has been banned
-	 *
-	 * INPUT:  array/string banned ips
-	 * OUTPUT: -
-	 * ERROR:  -
-	 */
-	function check_ip_bans($banned_ips) {
-		$banned_ips = explode(",", $banned_ips);
-
-		foreach ($banned_ips as $banned_ip) {
-			if (($banned_ip = trim($banned_ip)) == "") {
-				continue;
-			}
-			if (ip_match($_SERVER["REMOTE_ADDR"], $banned_ip)) {
-				header("Status: 403 Forbidden");
-				exit;
-			}
+    /* Remove dangerous characters from string
+     *
+     * INPUT:  string text
+     * OUTPUT: string text
+     * ERROR:  -
+     */
+	function secure_input($data) {
+		if (is_array($data) == false) {
+			$data = str_replace(chr(0), "", $data);
+			$special_chars = "/[".chr(1)."-".chr(8)."]|".
+							 "[".chr(11).chr(12)."]|".
+							 "[".chr(14)."-".chr(31)."]/";
+			$data = preg_replace($special_chars, "", $data);
+		} else foreach ($data as &$value) {
+			$value = secure_input($value);
 		}
+
+		return $data;
 	}
 
 	/* Validate input
@@ -93,7 +97,7 @@
 	 * ERROR:  -
 	 */
 	function valid_email($email) {
-		return eregi("^[0-9a-z]([-_.~]?[0-9a-z])*@[0-9a-z]([-.]?[0-9a-z])*\\.[a-z]{2,4}$", $email) != false;
+		return preg_match("/^[0-9A-Za-z]([-_.~]?[0-9A-Za-z])*@[0-9A-Za-z]([-.]?[0-9A-Za-z])*\\.[A-Za-z]{2,4}$/", $email) === 1;
 	}
 
 	/* Validate a date string
@@ -103,7 +107,7 @@
 	 * ERROR:  -
 	 */
 	function valid_date($date) {
-		return eregi("^[0-9]{4}-[0-9]{2}-[0-9]{2}$", $date) != false;
+		return preg_match("/^[0-9]{4}-[0-9]{2}-[0-9]{2}$/", $date) === 1;
 	}
 
 	/* Validate a time string
@@ -113,7 +117,7 @@
 	 * ERROR:  -
 	 */
 	function valid_time($time) {
-		return eregi("^(([01]?[0-9])|(2[0-3])):[0-5][0-9](:[0-5][0-9])?$", $time) != false;
+		return preg_match("/^(([01]?[0-9])|(2[0-3])):[0-5][0-9](:[0-5][0-9])?$/", $time) === 1;
 	}
 
 	/* Validate a timestamp
@@ -135,7 +139,7 @@
 	 */
 	function valid_phonenumber($phonenr) {
 		$phonenr = str_replace(" ", "", $phonenr);
-		return eregi("^(\+31|0)([0-9]{9}|6-?[0-9]{8}|[0-9]{2}-?[0-9]{7}|[0-9]{3}-?[0-9]{6})$", $phonenr) != false;
+		return preg_match("/^(\+31|0)([0-9]{9}|6-?[0-9]{8}|[0-9]{2}-?[0-9]{7}|[0-9]{3}-?[0-9]{6})$/", $phonenr) === 1;
 	}
 
 	/* Return a per-page overview of the access levels
@@ -144,9 +148,7 @@
 	 * OUTPUT: array( string page => int access level[, ....] )
 	 * ERROR:  false
 	 */
-	function page_access_list($db) {
-		global $_user;
-
+	function page_access_list($db, $user) {
 		$access_rights = array();
 
 		/* Public pages on disk
@@ -158,23 +160,23 @@
 
 		/* Private pages on disk
 		 */
-		$private = page_to_module(config_file("private_pages"));
-		foreach ($private as $page) {
-			$access_rights[$page] = $_user->is_admin ? YES : NO;
+		$private_pages = page_to_module(config_file("private_pages"));
+		foreach ($private_pages as $page) {
+			$access_rights[$page] = $user->is_admin ? YES : NO;
 		}
-		$access_rights["logout"] = $_user->logged_in ? YES : NO;
+		$access_rights["logout"] = $user->logged_in ? YES : NO;
 
-		if ($_user->logged_in && ($_user->is_admin == false)) {
+		if ($user->logged_in && ($user->is_admin == false)) {
 			$query = "select * from roles where id in ".
 					 "(select role_id from user_role where user_id=%d)";
-			if (($roles = $db->execute($query, $_user->id)) === false) {
+			if (($roles = $db->execute($query, $user->id)) === false) {
 				return false;
 			}
 			foreach ($roles as $role) {
 				$role = array_slice($role, 2);
 				foreach ($role as $page => $level) {
 					$level = (int)$level;
-					if ($_user->is_admin && ($level == 0)) {
+					if ($user->is_admin && ($level == 0)) {
 						$level = 1;
 					}
 					if (isset($access_rights[$page]) == false) {
@@ -192,12 +194,12 @@
 			return false;
 		}
 		foreach ($pages as $page) {
-			$access_rights[ltrim($page["url"], "/")] = is_false($page["private"]) || $_user->is_admin ? YES : NO;
+			$access_rights[ltrim($page["url"], "/")] = is_false($page["private"]) || $user->is_admin ? YES : NO;
 		}
 
-		if ($_user->logged_in && ($_user->is_admin == false)) {
+		if ($user->logged_in && ($user->is_admin == false)) {
 			$conditions = $rids = array();
-			foreach ($_user->role_ids as $rid) {
+			foreach ($user->role_ids as $rid) {
 				array_push($conditions, "role_id=%d");
 				array_push($rids, $rid);
 			}
@@ -219,6 +221,24 @@
 		return $access_rights;
 	}
 
+	/* Generate random string
+	 *
+	 * INPUT:  [int length]
+	 * OUTPUT: string random string
+	 * ERROR:  -
+	 */
+	function random_string($length = 32) {
+		$characters = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ01234567890";
+		$max_pos = strlen($characters) - 1;
+
+		$result = "";
+		while ($length-- > 0) {
+			$result .= $characters[mt_rand(0, $max_pos)];
+		}
+
+		return $result;
+	}
+
 	/* Get user's one time key
 	 *
 	 * INPUT:  object database, int user identifier
@@ -234,11 +254,25 @@
 			return $user["one_time_key"];
 		}
 
-		$key = md5(microtime().(string)rand());
+		$key = random_string();
 		if ($db->update("users", $user_id, array("one_time_key" => $key)) == false) {
 			return false;
 		}
 
 		return $key;
 	}
+
+	/* Validate captcha code
+	 *
+	 * INPUT:  string captcha code
+	 * OUTPUT: boolean captcha code valid
+	 * ERROR:  -
+	 */
+	function valid_captcha_code($code) {
+		if (isset($_SESSION["captcha_code"]) == false) {
+			return false;
+		}
+
+		return $_SESSION["captcha_code"] === $code;
+	}
 ?>
