@@ -1,5 +1,8 @@
 <?php
 	class host_statistics_model extends model {
+		private $types = array("requests", "bytes_sent", "bans", "exploit_attempts",
+				"result_forbidden", "result_not_found", "result_internal_error");
+
 		public function get_statistics($begin, $end, $filter_hostname, $filter_webserver) {
 			$query = "select * from host_statistics where ".
 					 "((timestamp_begin>%s and timestamp_begin<%s) or ".
@@ -20,15 +23,10 @@
 			$timestamp_begin = strtotime($begin);
 			$timestamp_end = strtotime($end);
 
-			$stats = array(
-				"requests"              => 0,
-				"bytes_sent"            => 0,
-				"bans"                  => 0,
-				"exploit_attempts"      => 0,
-				"result_forbidden"      => 0,
-				"result_not_found"      => 0,
-				"result_internal_error" => 0);
-			$stats_keys = array_keys($stats);
+			$stats = array();
+			foreach ($this->types as $key) {
+				$stats[$key] = 0;
+			}
 
 			$result = array();
 			$timestamp = $timestamp_begin;
@@ -45,7 +43,6 @@
 					return false;
 				}
 
-				#while (($entry = $this->db->fetch($resource)) !== false) {
 				foreach ($entries as $entry) {
 					$entry["timestamp_begin"] = strtotime($entry["timestamp_begin"]);
 					$entry["timestamp_end"] = strtotime($entry["timestamp_end"]);
@@ -80,12 +77,12 @@
 						}
 						$percentage = ($break - $entry["timestamp_begin"]) / $timespan;
 
-						foreach ($stats_keys as $key) {
+						foreach ($this->types as $key) {
 							$result[$day_end][$key] += (1 - $percentage) * $entry[$key];
 						}
 					}
 
-					foreach ($stats_keys as $key) {
+					foreach ($this->types as $key) {
 						$result[$day][$key] += $percentage * $entry[$key];
 					}
 				}
@@ -112,5 +109,31 @@
 
 			return $number;
 		}
+
+		public function get_day_information($type, $timestamp, $filter_hostname, $filter_webserver) {
+			if (in_array($type, $this->types) == false) {
+				return false;
+			}
+
+			$begin = date("Y-m-d 00:00:00", $timestamp);
+			$end = date("Y-m-d 23:59:59", $timestamp);
+
+			$query = "select sum(s.%S) as count, h.hostname from host_statistics s, hostnames h ".
+				"where s.hostname_id=h.id and timestamp_begin>=%s and timestamp_begin<=%s and %S>0 ";
+			$args = array($type, $begin, $end, $type);
+
+			if ($filter_hostname != 0) {
+				$query .= "and hostname_id=%d ";
+				array_push($args, $filter_hostname);
+			}
+			if ($filter_webserver != 0) {
+				$query .= "and webserver_id=%d ";
+				array_push($args, $filter_webserver);
+			}
+
+			$query .= "group by hostname_id order by count desc";
+
+			return $this->db->execute($query, $args);
+		}
 	}
 ?>
